# The Effects of PLU Polling Interval on the Reconstructed OD Matrix


## Overview
This repository contains the code, and supplementary materials associated with the research paper titled "The Effects of PLU Polling Interval on the Reconstructed OD Matrix: A Dutch Case Study Using a Data-Driven Method". The paper is published in the [TRR](https://journals-sagepub-com.tudelft.idm.oclc.org/doi/10.1177/03611981231158638).

## Table of Contents

- [Introduction](#introduction)
- [Repository Structure](#repository-structure)
- [Installation](#installation)
  - [Prerequisites](#prerequisites)
  - [Setting Up the Environment](#setting-up-the-environment)
- [Usage](#usage)
- [Datasets](#datasets)
- [License](#license)
- [Contact Information](#contact-information)
- [Reproducing Results](#reproducing-results)
- [License](#license)
- [Contact Information](#contact-information)
- [Acknowledgments](#acknowledgments)

## Introduction
This repository includes the implementation of models and analyses presented in the study, which investigates the effects of PLU Polling Interval on the Reconstructed OD Matrix the Netherlands.

## Repository Structure
The repository is organized as follows:
```bash
/project-root
│-- /phase4                                     # input and output data of the project. As the input data are sensetive, they will not be shared publically. 
|
|-- _1_deletingNotAllowedUsers.py               # 0) This Python notebook Query the allowed users for the research.
|-- _2_groundtruthODmatrix.py                   # 1) This Python notebook estimates the ground truth Origin-Destination matrix.
|-- _3_snapShotCompletion_preprocessing.py      # 2) This Python notebook prepares the MATSim data for different snapshot intervals 
|-- _4_processSnapshot.py                       # 3) This Python notebook pre-process MATSim prepared data for the analysis and OD matrix estimation. 
|-- _5_GSSI.ipynb                               # 4) In this Python notebook, we validate the OD matrices estimated from the previous steps to get an insight into how different polling intervals effect the quality of OD matrix.
|-- _6_0_estimatingLocProbability.ipynb         # 5) This notebook uses R language as the programming language to calculte zone probability for classification.
|-- _6_processSnapshot_zoneOnly.ipynb           # 6) In this Python notebook, we analyze the activity category identification with different variable (cross validation).
│-- README.md                                   # This README file
|-- LICENSE                                     # This the project LICENSE file            

│-- requirements.txt                            # Python dependencies
```
## Installation
### Prerequisites
- Python >=3.7
- Git
- Jupyter Notebook (if you wish to run the notebooks)
### Setting Up the Environment
- Clone the repository:
  
```bash
# Clone the repository
git clone <repository-url>
# Navigate to the project directory
cd <repository-directory>
```

- Install the required Python packages:
```bash
pip install -r requirements.txt
```
# Usage
To run the code provided in this repository, run the python notebooks acording to the order provided in the naming convention. Please make sure the input data is included in the data directory and the path to the input file is modified accordingly in each script.
# Datasets
The input datasets used in this study should be included in the /phase4 directory. As the project's datasets are either sensitve or too large to include directly in the repository, they can be accessed via TUDelft Research Drive link, or you may need to contact the associated point of contact at the time.

# License
This project is licensed under the MIT License - see the LICENSE file for details.

# Contact Information
For any inquiries, please contact the corresponding author of the paper, [Zahra Eftekhar](mailto: z.eftekhar2016@gmail.com)

# Acknowledgments
This research is sponsored by the NWO/TTW project MiRRORS under grant agreement 16270.


